@@ -1,9 +1,9 @@
 # coding=UTF-8
 #------------------------------------------------------------------------------
-# Copyright (c) 2007-2019, Acoular Development Team.
+# Copyright (c) Acoular Development Team.
 #------------------------------------------------------------------------------
 
 # separate file to find out about version without importing the acoular lib
 __author__ = "Acoular Development Team"
-__date__ = "13 August 2019"
-__version__ = "19.08"
+__date__ = "11 March 2024"
+__version__ = "24.03"
